check_error_should_terminate_stream

Function check_error_should_terminate_stream 

fn check_error_should_terminate_stream(err: &ChatbotErrorType) -> bool
These types of ChatbotErrors shouldn’t be shown to the user and are likely created from an unrecoverable error in our code that should make the stream fail.