fn check_error_should_terminate_stream(err: &ChatbotErrorType) -> boolExpand description
These types of ChatbotErrors shouldn’t be shown to the user and are likely created from an unrecoverable error in our code that should make the stream fail.
fn check_error_should_terminate_stream(err: &ChatbotErrorType) -> boolThese types of ChatbotErrors shouldn’t be shown to the user and are likely created from an unrecoverable error in our code that should make the stream fail.