fn error_event_string_from_message(
message: Option<&str>,
error: Option<&ChatbotError>,
) -> ChatbotResult<String>Expand description
Creates a ChatbotChatStreamEvent::Error from the message and returns it in string form. Either message or error should be Some. If message is Some, use it as the StreamEvent message. Else, use ChatbotError’s message. error is either a ResponseError received from Azure and stored in ChatbotError, or ChatbotError’s error message, or None.