pub async fn process_output_item(
conn: &mut PgConnection,
item: OutputItem,
conversation_id: Uuid,
app_config: &ApplicationConfiguration,
) -> ChatbotResult<ChatbotConversationMessage>Expand description
For saving output items that are not text messages or function calls, i.e. that don’t need further processing and are not streamed to the user. Saves reasoning and Azure AI items.